@@ -1,12 +1,12 @@
 /*
  * Copyright (c) 2011, 2012, 2013, 2014 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
+ * GNOME Books is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * GNOME Books is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
@@ -680,7 +680,7 @@ const DocCommon = new Lang.Class({
         if (this._thumbPath) {
             let [ slice, border ] = Utils.getThumbnailFrameBorder();
             thumbnailedPixbuf = Gd.embed_image_in_frame(emblemedPixbuf,
-                'resource:///org/gnome/Documents/ui/thumbnail-frame.png',
+                'resource:///org/gnome/Books/ui/thumbnail-frame.png',
                 slice, border);
         } else {
             thumbnailedPixbuf = emblemedPixbuf;
@@ -706,6 +706,7 @@ const DocCommon = new Lang.Class({
         Utils.debug('Loading ' + this.__name__ + ' ' + this.id + ' from ' + this.uriToLoad);
 
         if (this.mimeType == 'application/x-mobipocket-ebook' ||
+            this.mimeType == 'application/vnd.amazon.mobi8-ebook' ||
             this.mimeType == 'application/x-fictionbook+xml' ||
             this.mimeType == 'application/x-zip-compressed-fb2') {
             let exception = new GLib.Error(Gio.IOErrorEnum,
@@ -802,7 +803,7 @@ const DocCommon = new Lang.Class({
         let retval = '';
 
         if (this.collection)
-            retval = '{ ?urn nie:isPartOf <' + this.id + '> }';
+            retval = '{ ?urn nie:isLogicalPartOf <' + this.id + '> }';
 
         return retval;
     },
