@@ -1,12 +1,12 @@
 /*
  * Copyright (c) 2011 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
+ * GNOME Books is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * GNOME Books is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
@@ -33,8 +33,7 @@ pkg.require({ 'EvinceDocument': '3.0',
               'GLib': '2.0',
               'Gtk': '3.0',
               'GObject': '2.0',
-              'Tracker': '2.0',
-              'TrackerControl': '2.0',
+              'Tracker': '3.0',
               'WebKit2': '4.0' });
 
 const Application = imports.application;
