@@ -2,12 +2,12 @@
  * Copyright (c) 2015 Alessandro Bono
  * Copyright (c) 2011, 2013, 2015 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
+ * GNOME Books is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * GNOME Books is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
@@ -89,7 +89,7 @@ var MainToolbar = new Lang.Class({
     addMenuButton: function() {
       let model_name = null;
 
-      let builder = Gtk.Builder.new_from_resource("/org/gnome/Documents/ui/books-app-menu.ui");
+      let builder = Gtk.Builder.new_from_resource("/org/gnome/Books/ui/books-app-menu.ui");
       let model = builder.get_object('app-menu');
       let menuButton = new Gtk.MenuButton({ image: new Gtk.Image ({ icon_name: 'open-menu-symbolic' }),
                                             tooltip_text: Gettext.pgettext("menu button tooltip", "Menu"),
