@@ -1,12 +1,12 @@
 /*
  * Copyright (c) 2011, 2015 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
+ * GNOME Books is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * GNOME Books is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
@@ -305,6 +305,8 @@ const EmptyResultsBox = new Lang.Class({
             let docsPath, docsUrl;
 
             docsPath = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DOCUMENTS);
+            if (!docsPath)
+                docsPath = GLib.get_home_dir();
             docsUrl = Gio.file_new_for_path(docsPath).get_uri();
             useMarkup = true;
             /* translators: %s is the location of the Documents folder.*/
@@ -506,7 +508,7 @@ const OverviewToolbar = new Lang.Class({
         this.parent();
 
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Documents/ui/selection-menu.ui');
+        builder.add_from_resource('/org/gnome/Books/ui/selection-menu.ui');
         let selectionMenu = builder.get_object('selection-menu');
         this._selectionMenu = new Gtk.MenuButton({ menu_model: selectionMenu });
         this._selectionMenu.get_style_context().add_class('selection-menu');
@@ -537,7 +539,7 @@ const OverviewToolbar = new Lang.Class({
 
     _addViewMenuButton: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Documents/ui/view-menu.ui');
+        builder.add_from_resource('/org/gnome/Books/ui/view-menu.ui');
         let viewMenu = builder.get_object('viewMenu');
 
         // Translators: this is the menu to change view settings
