@@ -285,7 +285,7 @@ var Preview = new Lang.Class({
 
     createContextMenu: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Documents/ui/preview-context-menu.ui');
+        builder.add_from_resource('/org/gnome/Books/ui/preview-context-menu.ui');
         let model = builder.get_object('preview-context-menu');
         return Gtk.Menu.new_from_model(model);
     },
@@ -434,7 +434,7 @@ var PreviewToolbar = new Lang.Class({
 
     _getPreviewMenu: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/Documents/ui/preview-menu.ui');
+        builder.add_from_resource('/org/gnome/Books/ui/preview-menu.ui');
         let menu = builder.get_object('preview-menu');
 
         let doc = Application.documentManager.getActiveItem();
