@@ -2,12 +2,12 @@
  * Copyright © 2015 Alessandro Bono
  * Copyright (c) 2011 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
+ * GNOME Books is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * GNOME Books is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
@@ -597,7 +597,7 @@ const CollectionList = new Lang.Class({
 const OrganizeCollectionDialog = new Lang.Class({
     Name: 'OrganizeCollectionDialog',
     Extends: Gtk.Window,
-    Template: 'resource:///org/gnome/Documents/ui/organize-collection-dialog.ui',
+    Template: 'resource:///org/gnome/Books/ui/organize-collection-dialog.ui',
     InternalChildren: [ 'content',
                         'viewEmpty',
                         'addEntryEmpty',
@@ -845,7 +845,7 @@ const _SELECTION_TOOLBAR_DEFAULT_WIDTH = 500;
 var SelectionToolbar = new Lang.Class({
     Name: 'SelectionToolbar',
     Extends: Gtk.ActionBar,
-    Template: 'resource:///org/gnome/Documents/ui/selection-toolbar.ui',
+    Template: 'resource:///org/gnome/Books/ui/selection-toolbar.ui',
     InternalChildren: [ 'toolbarOpen',
                         'toolbarPrint',
                         'toolbarTrash',
